pub enum IndirectionKind {
Name(String),
Position(i64),
Star,
}Variants
Implementations
Sourceimpl IndirectionKind
impl IndirectionKind
Sourcepub fn as_name_mut(&mut self) -> Option<&mut String>
pub fn as_name_mut(&mut self) -> Option<&mut String>
Optionally returns mutable references to the inner fields if this is a IndirectionKind::Name, otherwise None
Sourcepub fn as_name(&self) -> Option<&String>
pub fn as_name(&self) -> Option<&String>
Optionally returns references to the inner fields if this is a IndirectionKind::Name, otherwise None
Sourcepub fn into_name(self) -> Result<String, Self>
pub fn into_name(self) -> Result<String, Self>
Returns the inner fields if this is a IndirectionKind::Name, otherwise returns back the enum in the Err case of the result
Sourcepub unsafe fn into_name_unchecked(self) -> String
pub unsafe fn into_name_unchecked(self) -> String
Unchecked return of the inner fields of IndirectionKind::Name.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_name_unchecked(&self) -> &String
pub unsafe fn as_name_unchecked(&self) -> &String
Unchecked reference of the inner fields of IndirectionKind::Name.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_name_mut_unchecked(&mut self) -> &mut String
pub unsafe fn as_name_mut_unchecked(&mut self) -> &mut String
Unchecked mutable reference of the inner fields of IndirectionKind::Name.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub fn is_position(&self) -> bool
pub fn is_position(&self) -> bool
Returns true if this is a IndirectionKind::Position, otherwise false
Sourcepub fn as_position_mut(&mut self) -> Option<&mut i64>
pub fn as_position_mut(&mut self) -> Option<&mut i64>
Optionally returns mutable references to the inner fields if this is a IndirectionKind::Position, otherwise None
Sourcepub fn as_position(&self) -> Option<&i64>
pub fn as_position(&self) -> Option<&i64>
Optionally returns references to the inner fields if this is a IndirectionKind::Position, otherwise None
Sourcepub fn into_position(self) -> Result<i64, Self>
pub fn into_position(self) -> Result<i64, Self>
Returns the inner fields if this is a IndirectionKind::Position, otherwise returns back the enum in the Err case of the result
Sourcepub unsafe fn into_position_unchecked(self) -> i64
pub unsafe fn into_position_unchecked(self) -> i64
Unchecked return of the inner fields of IndirectionKind::Position.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_position_unchecked(&self) -> &i64
pub unsafe fn as_position_unchecked(&self) -> &i64
Unchecked reference of the inner fields of IndirectionKind::Position.
Safety
Results in undefined behavior when it is the incorrect variant.
Sourcepub unsafe fn as_position_mut_unchecked(&mut self) -> &mut i64
pub unsafe fn as_position_mut_unchecked(&mut self) -> &mut i64
Unchecked mutable reference of the inner fields of IndirectionKind::Position.
Safety
Results in undefined behavior when it is the incorrect variant.